@@ -1,5 +1,7 @@
 var NAVTREEINDEX118 =
 {
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a112bf563da59027f439e6c9c14b3b8c2":[4,0,7,1,0,0,22],
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a1174ccc1fcb0d289543b66c934d9d1ef":[3,0,10,2,0,0,11],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a1174ccc1fcb0d289543b66c934d9d1ef":[4,0,7,1,0,0,11],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a1aed6d3bcd84865fd4c97669462d8d1e":[3,0,10,2,0,0,6],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a1aed6d3bcd84865fd4c97669462d8d1e":[4,0,7,1,0,0,6],
@@ -247,7 +249,5 @@ var NAVTREEINDEX118 =
 "structzypp_1_1debug_1_1Tm.html#a5ce6fbb08ad839316c804d123b97dd60":[3,0,10,5,2,8],
 "structzypp_1_1debug_1_1Tm.html#a5ce6fbb08ad839316c804d123b97dd60":[4,0,7,4,2,8],
 "structzypp_1_1debug_1_1Tm.html#a5e9aa458c9abcbc7de9c9fa6eddbf987":[3,0,10,5,2,9],
-"structzypp_1_1debug_1_1Tm.html#a5e9aa458c9abcbc7de9c9fa6eddbf987":[4,0,7,4,2,9],
-"structzypp_1_1debug_1_1Tm.html#a6d6a6f343f3cd6121d893f74bac332f2":[3,0,10,5,2,2],
-"structzypp_1_1debug_1_1Tm.html#a6d6a6f343f3cd6121d893f74bac332f2":[4,0,7,4,2,2]
+"structzypp_1_1debug_1_1Tm.html#a5e9aa458c9abcbc7de9c9fa6eddbf987":[4,0,7,4,2,9]
 };
