@@ -1,5 +1,7 @@
 var NAVTREEINDEX123 =
 {
+"structzypp_1_1pool_1_1PoolStats.html":[3,0,10,29,4],
+"structzypp_1_1pool_1_1PoolStats.html":[4,0,7,26,4],
 "structzypp_1_1pool_1_1PoolStats.html#a22e290d7386d2ad66bee641e63d18875":[3,0,10,29,4,1],
 "structzypp_1_1pool_1_1PoolStats.html#a22e290d7386d2ad66bee641e63d18875":[4,0,7,26,4,1],
 "structzypp_1_1pool_1_1PoolStats.html#a34934a266119c662efde83666bf78d8e":[3,0,10,29,4,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX123 =
 "structzypp_1_1repo_1_1RepoReport.html#a665d08a891a115a66946efd10d2aad03":[3,0,10,32,22,4],
 "structzypp_1_1repo_1_1RepoReport.html#a665d08a891a115a66946efd10d2aad03":[4,0,7,27,21,4],
 "structzypp_1_1repo_1_1RepoType.html":[3,0,10,32,23],
-"structzypp_1_1repo_1_1RepoType.html":[4,0,7,27,22],
-"structzypp_1_1repo_1_1RepoType.html#a3f120be27bd25931a92debeafcfa6cd5":[3,0,10,32,23,5],
-"structzypp_1_1repo_1_1RepoType.html#a3f120be27bd25931a92debeafcfa6cd5":[4,0,7,27,22,5]
+"structzypp_1_1repo_1_1RepoType.html":[4,0,7,27,22]
 };
