@@ -1,19 +1,5 @@
 var NAVTREEINDEX131 =
 {
-"structzyppng_1_1AsyncOp.html#aa15738cae5f953a0f23ac8eda5b4514c":[4,0,9,13,2],
-"structzyppng_1_1AsyncOp.html#ab3292dc53772699844783907a46112fb":[3,0,13,51,12],
-"structzyppng_1_1AsyncOp.html#ab3292dc53772699844783907a46112fb":[4,0,9,13,12],
-"structzyppng_1_1AsyncOp.html#ac09ea211f9be3ed78a7fd60f0fd87022":[3,0,13,51,3],
-"structzyppng_1_1AsyncOp.html#ac09ea211f9be3ed78a7fd60f0fd87022":[4,0,9,13,3],
-"structzyppng_1_1AsyncOp.html#ac6392e0a3c627e231d72222b78876151":[3,0,13,51,1],
-"structzyppng_1_1AsyncOp.html#ac6392e0a3c627e231d72222b78876151":[4,0,9,13,1],
-"structzyppng_1_1AsyncOp.html#adc8fd999dd928aad4be0896d46b97dbd":[3,0,13,51,10],
-"structzyppng_1_1AsyncOp.html#adc8fd999dd928aad4be0896d46b97dbd":[4,0,9,13,10],
-"structzyppng_1_1AsyncOp.html#ae0a2fabe76a62f0cb05ba100e31122ed":[3,0,13,51,5],
-"structzyppng_1_1AsyncOp.html#ae0a2fabe76a62f0cb05ba100e31122ed":[4,0,9,13,5],
-"structzyppng_1_1AutoDisconnect.html":[3,0,13,61],
-"structzyppng_1_1AutoDisconnect.html":[4,0,9,23],
-"structzyppng_1_1AutoDisconnect.html#a2a219be366abbfec1f2c856907d2de7d":[3,0,13,61,4],
 "structzyppng_1_1AutoDisconnect.html#a2a219be366abbfec1f2c856907d2de7d":[4,0,9,23,4],
 "structzyppng_1_1AutoDisconnect.html#a39c253bb59fa2c70598784d1436ae1f3":[3,0,13,61,0],
 "structzyppng_1_1AutoDisconnect.html#a39c253bb59fa2c70598784d1436ae1f3":[4,0,9,23,0],
@@ -249,5 +235,19 @@ var NAVTREEINDEX131 =
 "structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html":[4,0,9,80,2],
 "structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a17cee02f579807e61a491ced6a6f5705":[3,0,13,118,2,1],
 "structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a17cee02f579807e61a491ced6a6f5705":[4,0,9,80,2,1],
-"structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a91c8dfd6b2be5797693b71e268b92d5d":[3,0,13,118,2,0]
+"structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a91c8dfd6b2be5797693b71e268b92d5d":[3,0,13,118,2,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a91c8dfd6b2be5797693b71e268b92d5d":[4,0,9,80,2,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html":[3,0,13,118,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html":[4,0,9,80,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#a22dde46a05a23d9606a519a7578e7455":[3,0,13,118,3,2],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#a22dde46a05a23d9606a519a7578e7455":[4,0,9,80,3,2],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#aba1b459e0df35418dc8d728bc6ba946e":[3,0,13,118,3,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#aba1b459e0df35418dc8d728bc6ba946e":[4,0,9,80,3,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#ad9448873c442a109ac347a0a74c42549":[3,0,13,118,3,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#ad9448873c442a109ac347a0a74c42549":[4,0,9,80,3,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#af0920720763b320f2d82396a1112d971":[3,0,13,118,3,1],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#af0920720763b320f2d82396a1112d971":[4,0,9,80,3,1],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html":[3,0,13,118,4],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html":[4,0,9,80,4],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a2325a771118296af7315f3ddca14a088":[3,0,13,118,4,10]
 };
