@@ -1,5 +1,7 @@
 var NAVTREEINDEX132 =
 {
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a2325a771118296af7315f3ddca14a088":[4,0,9,80,4,10],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a4cd9e6a27e064d0f5dcf639b9f74190e":[3,0,13,118,4,6],
 "structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a4cd9e6a27e064d0f5dcf639b9f74190e":[4,0,9,80,4,6],
 "structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a572bf76e76041db3bb7c5e12600f43b3":[3,0,13,118,4,5],
 "structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a572bf76e76041db3bb7c5e12600f43b3":[4,0,9,80,4,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX132 =
 "structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[4,0,9,124,5,1],
 "structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[3,0,13,162,5,3],
 "structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[4,0,9,124,5,3],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[3,0,13,162,5,2],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[4,0,9,124,5,2],
-"structzyppng_1_1Statemachine_1_1__InitialState.html":[3,0,13,163,0]
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[3,0,13,162,5,2]
 };
