@@ -1,19 +1,5 @@
 var NAVTREEINDEX133 =
 {
-"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[4,0,9,124,3,2],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html":[3,0,13,162,4],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html":[4,0,9,124,4],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html#aedf0a23e304986ec54ca24bb1f219322":[3,0,13,162,4,0],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html#aedf0a23e304986ec54ca24bb1f219322":[4,0,9,124,4,0],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html":[3,0,13,162,5],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html":[4,0,9,124,5],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a2c4c0e2d5b3f1867bf5652eb43cc87de":[3,0,13,162,5,0],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a2c4c0e2d5b3f1867bf5652eb43cc87de":[4,0,9,124,5,0],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[3,0,13,162,5,1],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[4,0,9,124,5,1],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[3,0,13,162,5,3],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[4,0,9,124,5,3],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[3,0,13,162,5,2],
 "structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[4,0,9,124,5,2],
 "structzyppng_1_1Statemachine_1_1__InitialState.html":[3,0,13,163,0],
 "structzyppng_1_1Statemachine_1_1__InitialState.html":[4,0,9,125,0],
@@ -249,5 +235,19 @@ var NAVTREEINDEX133 =
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#a9be1d5ad01279d2fe81bf92353a54b8e":[4,0,9,1,52,6],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#aa8c26484ffe2ada4d018041e1e46b39a":[3,0,13,15,52,7],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#aa8c26484ffe2ada4d018041e1e46b39a":[4,0,9,1,52,7],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#ac7169f1ca12b0205cde87c2fee9dd844":[3,0,13,15,52,2]
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#ac7169f1ca12b0205cde87c2fee9dd844":[3,0,13,15,52,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#ac7169f1ca12b0205cde87c2fee9dd844":[4,0,9,1,52,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#acb09daead5ac798f740cc21b4685199d":[3,0,13,15,52,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#acb09daead5ac798f740cc21b4685199d":[4,0,9,1,52,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#af9a1b1b6fdad0f26ac02d94e5c6d6110":[3,0,13,15,52,1],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#af9a1b1b6fdad0f26ac02d94e5c6d6110":[4,0,9,1,52,1],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html":[3,0,13,15,51],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html":[4,0,9,1,51],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#a32d23b4ce87bf2527923b02d55820804":[3,0,13,15,51,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#a32d23b4ce87bf2527923b02d55820804":[4,0,9,1,51,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa1d9b1a569233b0dba0a1d2e7227b035":[3,0,13,15,51,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa1d9b1a569233b0dba0a1d2e7227b035":[4,0,9,1,51,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa419ee11f494159cddd1eeccb34c532c":[3,0,13,15,51,7],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa419ee11f494159cddd1eeccb34c532c":[4,0,9,1,51,7],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ab8db9840a5595d0d560bfc79598e5ad4":[3,0,13,15,51,3]
 };
