@@ -1,5 +1,7 @@
 var NAVTREEINDEX134 =
 {
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ab8db9840a5595d0d560bfc79598e5ad4":[4,0,9,1,51,3],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac09b48c9cfe5e00bfd6376fd24a3fded":[3,0,13,15,51,6],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac09b48c9cfe5e00bfd6376fd24a3fded":[4,0,9,1,51,6],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac146358fa4b635eb08959d5a6879d425":[3,0,13,15,51,1],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac146358fa4b635eb08959d5a6879d425":[4,0,9,1,51,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX134 =
 "structzyppng_1_1detail_1_1or__else__helper.html#a179fd1e8d51de8c8d4ada28c07d01658":[4,0,9,1,48,0],
 "structzyppng_1_1detail_1_1or__else__helper.html#a6c8ad53ee2f67c3e7ad7ee9af5a51a0d":[3,0,13,15,48,2],
 "structzyppng_1_1detail_1_1or__else__helper.html#a6c8ad53ee2f67c3e7ad7ee9af5a51a0d":[4,0,9,1,48,2],
-"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[3,0,13,15,48,1],
-"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[4,0,9,1,48,1],
-"structzyppng_1_1detail_1_1showme.html":[3,0,13,15,56]
+"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[3,0,13,15,48,1]
 };
