@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"PluginScriptException_8h.html#a21ab8f4173229c8183ba697ec92cae2a":[5,0,0,101,1],
 "PluginScriptException_8h_source.html":[5,0,0,101],
 "PluginScript_8cc.html":[5,0,0,98],
 "PluginScript_8cc.html#ad11ca1dc9757eafa29e9de2259388ff4":[5,0,0,98,1],
@@ -88,8 +89,8 @@ var NAVTREEINDEX2 =
 "ProxyInfoLibproxy_8h_source.html":[5,0,0,1,1,1],
 "ProxyInfoSysconfig_8h.html":[5,0,0,1,1,3],
 "ProxyInfoSysconfig_8h_source.html":[5,0,0,1,1,3],
-"ProxyInfo_8h.html":[5,0,0,1,42],
-"ProxyInfo_8h_source.html":[5,0,0,1,42],
+"ProxyInfo_8h.html":[5,0,0,1,40],
+"ProxyInfo_8h_source.html":[5,0,0,1,40],
 "ProxyInfos_8h.html":[5,0,0,1,1,2],
 "ProxyInfos_8h_source.html":[5,0,0,1,1,2],
 "PublicKey_8h.html":[5,0,0,119],
@@ -248,6 +249,5 @@ var NAVTREEINDEX2 =
 "Resolvable_8cc.html":[5,0,0,144],
 "Resolvable_8cc_source.html":[5,0,0,144],
 "Resolvable_8h.html":[5,0,0,145],
-"Resolvable_8h_source.html":[5,0,0,145],
-"ResolverFocus_8cc.html":[5,0,0,148]
+"Resolvable_8h_source.html":[5,0,0,145]
 };
