@@ -1,5 +1,7 @@
 var NAVTREEINDEX33 =
 {
+"classzypp_1_1ResPoolProxy.html#afa1602f0353acc490827263e100b7212":[4,0,7,205,24],
+"classzypp_1_1ResPoolProxy.html#affdda0a780f6910e6909303f109fefd5":[3,0,10,214,43],
 "classzypp_1_1ResPoolProxy.html#affdda0a780f6910e6909303f109fefd5":[4,0,7,205,43],
 "classzypp_1_1ResPool_1_1EstablishedStates.html":[3,0,10,213,0],
 "classzypp_1_1ResPool_1_1EstablishedStates.html":[4,0,7,204,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX33 =
 "classzypp_1_1ResStatus.html#ac9a55549ea64c8d1014703ff723bc48b":[3,0,10,215,1],
 "classzypp_1_1ResStatus.html#ac9a55549ea64c8d1014703ff723bc48b":[4,0,7,206,1],
 "classzypp_1_1ResStatus.html#aca451c83ff9be50b547fb0986b917187":[3,0,10,215,6],
-"classzypp_1_1ResStatus.html#aca451c83ff9be50b547fb0986b917187":[4,0,7,206,6],
-"classzypp_1_1ResStatus.html#ace132e1611a1aea34fb243d297551fe2":[3,0,10,215,98],
-"classzypp_1_1ResStatus.html#ace132e1611a1aea34fb243d297551fe2":[4,0,7,206,98]
+"classzypp_1_1ResStatus.html#aca451c83ff9be50b547fb0986b917187":[4,0,7,206,6]
 };
