@@ -1,5 +1,7 @@
 var NAVTREEINDEX52 =
 {
+"classzypp_1_1media_1_1MediaManager.html#a47eabf6506ddbecbd0cd73bc0e52794d":[3,0,10,25,42,30],
+"classzypp_1_1media_1_1MediaManager.html#a47eabf6506ddbecbd0cd73bc0e52794d":[4,0,7,22,42,30],
 "classzypp_1_1media_1_1MediaManager.html#a4ad8d3535fa1f04920fe823e8b04849a":[3,0,10,25,42,31],
 "classzypp_1_1media_1_1MediaManager.html#a4ad8d3535fa1f04920fe823e8b04849a":[4,0,7,22,42,31],
 "classzypp_1_1media_1_1MediaManager.html#a569396e2c9b71a9ee850ccd4e435890d":[3,0,10,25,42,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX52 =
 "classzypp_1_1media_1_1MediaNotOpenException.html#a0e565696d1dcf49cc48b09cf5501ec57":[3,0,10,25,52,1],
 "classzypp_1_1media_1_1MediaNotOpenException.html#a0e565696d1dcf49cc48b09cf5501ec57":[4,0,7,22,52,1],
 "classzypp_1_1media_1_1MediaNotOpenException.html#a70b9c29895680e92d5bdc9571402ee01":[3,0,10,25,52,3],
-"classzypp_1_1media_1_1MediaNotOpenException.html#a70b9c29895680e92d5bdc9571402ee01":[4,0,7,22,52,3],
-"classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[3,0,10,25,52,0],
-"classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[4,0,7,22,52,0]
+"classzypp_1_1media_1_1MediaNotOpenException.html#a70b9c29895680e92d5bdc9571402ee01":[4,0,7,22,52,3]
 };
