@@ -1,5 +1,7 @@
 var NAVTREEINDEX53 =
 {
+"classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[3,0,10,25,52,0],
+"classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[4,0,7,22,52,0],
 "classzypp_1_1media_1_1MediaNotOpenException.html#ae09662c4833daf1f31fbf0da14799d3d":[3,0,10,25,52,2],
 "classzypp_1_1media_1_1MediaNotOpenException.html#ae09662c4833daf1f31fbf0da14799d3d":[4,0,7,22,52,2],
 "classzypp_1_1media_1_1MediaNotSupportedException.html":[3,0,10,25,53],
@@ -247,7 +249,5 @@ var NAVTREEINDEX53 =
 "classzypp_1_1media_1_1NoVerifier.html#af766a20b9aee866f24b343e218e49ae0":[4,0,7,22,71,0],
 "classzypp_1_1media_1_1ProxyInfo.html":[3,0,10,25,72],
 "classzypp_1_1media_1_1ProxyInfo.html":[4,0,7,22,72],
-"classzypp_1_1media_1_1ProxyInfo.html#a0fbd9637101234cc9a9cb2e81b733d09":[3,0,10,25,72,10],
-"classzypp_1_1media_1_1ProxyInfo.html#a0fbd9637101234cc9a9cb2e81b733d09":[4,0,7,22,72,10],
-"classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[3,0,10,25,72,13]
+"classzypp_1_1media_1_1ProxyInfo.html#a0fbd9637101234cc9a9cb2e81b733d09":[3,0,10,25,72,10]
 };
