@@ -1,5 +1,7 @@
 var NAVTREEINDEX54 =
 {
+"classzypp_1_1media_1_1ProxyInfo.html#a0fbd9637101234cc9a9cb2e81b733d09":[4,0,7,22,72,10],
+"classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[3,0,10,25,72,13],
 "classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[4,0,7,22,72,13],
 "classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[3,0,10,25,72,9],
 "classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[4,0,7,22,72,9],
@@ -247,7 +249,5 @@ var NAVTREEINDEX54 =
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#abd6b179a7361bfadfb0c4a71159b7674":[4,0,7,22,77,0,6],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac398cad18a37074b89cd893db9a56a4d":[3,0,10,25,77,0,27],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac398cad18a37074b89cd893db9a56a4d":[4,0,7,22,77,0,27],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac509a54a6841056310c9a1cd9f40140c":[3,0,10,25,77,0,12],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac509a54a6841056310c9a1cd9f40140c":[4,0,7,22,77,0,12],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[3,0,10,25,77,0,4]
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac509a54a6841056310c9a1cd9f40140c":[3,0,10,25,77,0,12]
 };
