@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"classztui_1_1Out.html#a4ee51890e9d409a39049d6f17ba1a5a2":[4,0,6,12,38],
 "classztui_1_1Out.html#a54742c0395209a7bdef24580deeff2f9":[3,0,9,15,64],
 "classztui_1_1Out.html#a54742c0395209a7bdef24580deeff2f9":[4,0,6,12,64],
 "classztui_1_1Out.html#a5f799b060a28f0b51be64327e8659d23":[3,0,9,15,48],
@@ -248,6 +249,5 @@ var NAVTREEINDEX6 =
 "classztui_1_1PromptOptions.html#ab348508de43bc6e67d0cee11c8a2b67b":[4,0,6,14,24],
 "classztui_1_1PromptOptions.html#abe025fc1ae02a37d90ca10bb69100d0b":[3,0,9,17,0],
 "classztui_1_1PromptOptions.html#abe025fc1ae02a37d90ca10bb69100d0b":[4,0,6,14,0],
-"classztui_1_1PromptOptions.html#ac007d644af02e1903169fc33cddb20c0":[3,0,9,17,10],
-"classztui_1_1PromptOptions.html#ac007d644af02e1903169fc33cddb20c0":[4,0,6,14,10]
+"classztui_1_1PromptOptions.html#ac007d644af02e1903169fc33cddb20c0":[3,0,9,17,10]
 };
