@@ -1,5 +1,7 @@
 var NAVTREEINDEX68 =
 {
+"classzypp_1_1str_1_1regex.html#af0f734f8837667359c75863be23b5575":[2,11,0,3],
+"classzypp_1_1str_1_1smatch.html":[2,11,1],
 "classzypp_1_1str_1_1smatch.html#a58c9bb5a97d50e56498768541dcbd8fb":[2,11,1,0],
 "classzypp_1_1str_1_1smatch.html#a823cb1fa9ccbeeba04a579d5a30c809a":[2,11,1,2],
 "classzypp_1_1str_1_1smatch.html#a88d6e57f9c71cb8a2e642786cbf2837b":[2,11,1,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX68 =
 "classzypp_1_1target_1_1HardLocksFile.html#acaed020ac94026ce2edc7d86c5620bf0":[3,0,10,43,4,8],
 "classzypp_1_1target_1_1HardLocksFile.html#acaed020ac94026ce2edc7d86c5620bf0":[3,0,10,43,4,9],
 "classzypp_1_1target_1_1HardLocksFile.html#acaed020ac94026ce2edc7d86c5620bf0":[4,0,7,36,4,8],
-"classzypp_1_1target_1_1HardLocksFile.html#acaed020ac94026ce2edc7d86c5620bf0":[4,0,7,36,4,9],
-"classzypp_1_1target_1_1Modalias.html":[3,0,10,43,6],
-"classzypp_1_1target_1_1Modalias.html":[4,0,7,36,6]
+"classzypp_1_1target_1_1HardLocksFile.html#acaed020ac94026ce2edc7d86c5620bf0":[4,0,7,36,4,9]
 };
