@@ -1,5 +1,7 @@
 var NAVTREEINDEX80 =
 {
+"classzyppng_1_1DigestReportHelper.html#ad09b2e0a175113643d6c18fbc2549a5a":[4,0,9,35,7],
+"classzyppng_1_1DigestReportHelper.html#ae67ca79ff64346fca86c32b64411cc7f":[3,0,13,73,5],
 "classzyppng_1_1DigestReportHelper.html#ae67ca79ff64346fca86c32b64411cc7f":[4,0,9,35,5],
 "classzyppng_1_1DigestReportHelper.html#afbba73ad5e8cfca811a651c515063019":[3,0,13,73,4],
 "classzyppng_1_1DigestReportHelper.html#afbba73ad5e8cfca811a651c515063019":[4,0,9,35,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX80 =
 "classzyppng_1_1HeaderValueMap.html#ac8fa34c883d2b3b292d8dcc08571ed45":[4,0,9,56,11],
 "classzyppng_1_1HeaderValueMap.html#ad5854af397e01ed930e604c38ff90cc1":[3,0,13,94,7],
 "classzyppng_1_1HeaderValueMap.html#ad5854af397e01ed930e604c38ff90cc1":[4,0,9,56,7],
-"classzyppng_1_1HeaderValueMap.html#ad661cd20dbef4446317a2364c9102688":[3,0,13,94,6],
-"classzyppng_1_1HeaderValueMap.html#ad661cd20dbef4446317a2364c9102688":[4,0,9,56,6],
-"classzyppng_1_1HeaderValueMap.html#ad8b182fea8b9f88192774ec2786f39f9":[3,0,13,94,12]
+"classzyppng_1_1HeaderValueMap.html#ad661cd20dbef4446317a2364c9102688":[3,0,13,94,6]
 };
